==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/workloads/kotlin/inputs/ExtendedLocationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.workloads.kotlin.inputs

import com.pulumi.azurenative.workloads.inputs.ExtendedLocationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The extended location definition.
 * @property name The extended location name.
 * @property type The extended location type.
 */
public data class ExtendedLocationArgs(
    public val name: Output<String>,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.workloads.inputs.ExtendedLocationArgs> {
    override fun toJava(): com.pulumi.azurenative.workloads.inputs.ExtendedLocationArgs =
        com.pulumi.azurenative.workloads.inputs.ExtendedLocationArgs.builder()
            .name(name.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ExtendedLocationArgs].
 */
@PulumiTagMarker
public class ExtendedLocationArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var type: Output<String>? = null

    /**
     * @param value The extended location name.
     */
    @JvmName("trpkbdihiwpfdpvk")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The extended location type.
     */
    @JvmName("ocukdiktbdisqmiv")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value The extended location name.
     */
    @JvmName("meakhknexkegwnql")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The extended location type.
     */
    @JvmName("gjsulmhdjrtdyaqg")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ExtendedLocationArgs = ExtendedLocationArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/workloads/kotlin/inputs/ExtendedLocationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.workloads.kotlin.inputs

import com.pulumi.azurenative.workloads.inputs.ExtendedLocationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The extended location definition.
 * @property name The extended location name.
 * @property type The extended location type.
 */
public data class ExtendedLocationArgs(
    public val name: Output<String>,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.workloads.inputs.ExtendedLocationArgs> {
    override fun toJava(): com.pulumi.azurenative.workloads.inputs.ExtendedLocationArgs =
        com.pulumi.azurenative.workloads.inputs.ExtendedLocationArgs.builder()
            .name(name.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ExtendedLocationArgs].
 */
@PulumiTagMarker
public class ExtendedLocationArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var type: Output<String>? = null

    /**
     * @param value The extended location name.
     */
    @JvmName("gmaerfommlrsqwfh")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The extended location type.
     */
    @JvmName("cjrobhpdwauhjuxd")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value The extended location name.
     */
    @JvmName("jtibjeytkrrltlqn")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The extended location type.
     */
    @JvmName("rkxdfgshjxuhdlhi")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ExtendedLocationArgs = ExtendedLocationArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
